"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasFiles = exports.hasFilesDeep = exports.objectToFormData = void 0;
const objects_1 = require("./objects");
function objectToFormData(object, formData = new FormData(), parent = '') {
    if (object === null || object === 'undefined' || object.length === 0) {
        formData.append(parent, object);
    }
    else {
        for (const property in object) {
            if ((0, objects_1.hasOwnProperty)(object, property)) {
                appendToFormData(formData, getKey(parent, property), object[property]);
            }
        }
    }
    return formData;
}
exports.objectToFormData = objectToFormData;
function getKey(parent, property) {
    return parent ? parent + '[' + property + ']' : property;
}
function appendToFormData(formData, key, value) {
    if (value instanceof Date) {
        return formData.append(key, value.toISOString());
    }
    if (value instanceof File) {
        return formData.append(key, value, value.name);
    }
    if (typeof value === 'boolean') {
        return formData.append(key, value ? '1' : '0');
    }
    if (value === null) {
        return formData.append(key, '');
    }
    if (typeof value !== 'object') {
        return formData.append(key, value);
    }
    if ((0, objects_1.isArray)(value) && hasFilesDeep(value)) {
        for (let i = 0; i < value.length; i++) {
            formData.append(key + '[' + i + ']', value[i], value[i].name);
        }
        return formData;
    }
    objectToFormData(value, formData, key);
}
function hasFilesDeep(object) {
    if (object === null) {
        return false;
    }
    if (typeof object === 'object') {
        for (const key in object) {
            if ((0, objects_1.hasOwnProperty)(object, key)) {
                if ((0, objects_1.isFile)(object[key])) {
                    return true;
                }
            }
        }
    }
    if ((0, objects_1.isArray)(object)) {
        for (const key in object) {
            if ((0, objects_1.hasOwnProperty)(object, key)) {
                return hasFilesDeep(object[key]);
            }
        }
    }
    return (0, objects_1.isFile)(object);
}
exports.hasFilesDeep = hasFilesDeep;
function hasFiles(form) {
    for (const prop in form) {
        const hasProp = (0, objects_1.hasOwnProperty)(form, prop) || typeof window !== 'undefined';
        if (hasProp && hasFilesDeep(form[prop])) {
            return true;
        }
    }
    return false;
}
exports.hasFiles = hasFiles;
