"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isPlainObject = exports.isObject = exports.is = exports.cloneDeep = exports.merge = exports.isFile = exports.hasOwnProperty = exports.isArray = void 0;
function isArray(object) {
    return Object.prototype.toString.call(object) === '[object Array]';
}
exports.isArray = isArray;
function hasOwnProperty(obj, key) {
    if (!obj || !key)
        return false;
    return Object.prototype.hasOwnProperty.call(obj, key);
}
exports.hasOwnProperty = hasOwnProperty;
function isFile(object) {
    if (typeof window === 'undefined' ||
        typeof File !== 'function' ||
        typeof FileList !== 'function') {
        return false;
    }
    return object instanceof File || object instanceof FileList;
}
exports.isFile = isFile;
function merge(a, b) {
    for (const key in b) {
        if (hasOwnProperty(b, key)) {
            a[key] = cloneDeep(b[key]);
        }
    }
    return a;
}
exports.merge = merge;
function cloneDeep(object) {
    if (object === null) {
        return null;
    }
    if (isFile(object)) {
        return object;
    }
    if (isArray(object)) {
        const clone = [];
        for (const key in object) {
            if (hasOwnProperty(object, key)) {
                clone[key] = cloneDeep(object[key]);
            }
        }
        return clone;
    }
    if (typeof object === 'object') {
        const clone = {};
        for (const key in object) {
            if (hasOwnProperty(object, key)) {
                clone[key] = cloneDeep(object[key]);
            }
        }
        return clone;
    }
    return object;
}
exports.cloneDeep = cloneDeep;
function is(errors, error) {
    return isArray(error)
        ? error.some((w) => is(errors, w))
        : errors.includes(error);
}
exports.is = is;
function isObject(value) {
    return Object.prototype.toString.call(value) === '[object Object]';
}
exports.isObject = isObject;
function isPlainObject(value) {
    if (!isObject(value))
        return false;
    const ctor = value.constructor;
    if (ctor === undefined)
        return true;
    const prot = ctor.prototype;
    if (!isObject(prot))
        return false;
    return hasOwnProperty(prot, 'isPrototypeOf');
}
exports.isPlainObject = isPlainObject;
